Date: 08 29, 2001 10:57:30 AM

# About Text Files

This "section" describes ways to manage text files, primarily within the Text Tab.

Plain text files are usually suffixed with .txt, while HTML files are suffixed with .htm or .html and are displayed with a globe icon in the text tab.

When a text in the Text Tab has been analyzed, its icon gets a red check mark. A plus sign appears to its left, indicating that log files, dump files, and output files can be viewed under it.